@@ -23,7 +23,7 @@ use WebService::DMM::Series;
 
 use utf8;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 my $agent_name = __PACKAGE__ . "/$VERSION";
 our $UserAgent = Furl->new(agent => $agent_name);
@@ -60,11 +60,13 @@ sub _validate_affiliate_id {
 }
 
 my %validate_table = (
-    hits   => \&_validate_hits_param,
-    offset => \&_validate_offset_param,
-    sort   => \&_validate_sort_param,
+    hits    => \&_validate_hits_param,
+    offset  => \&_validate_offset_param,
+    sort    => \&_validate_sort_param,
 );
 
+my $ROOT_NODE;
+
 sub search {
     my ($self, %args) = @_;
 
@@ -74,7 +76,7 @@ sub search {
     $param{affiliate_id} = $self->{affiliate_id};
     $param{api_id}       = $self->{api_id};
     $param{operation}    = $args{operation} || 'ItemList';
-    $param{version}      = '1.00';
+    $param{version}      = _validate_version_param($args{version});
     $param{timestamp}    = $args{timestamp} || _format_date();
     $param{site}         = _validate_site_param($args{site});
 
@@ -97,14 +99,38 @@ sub search {
         $param{keyword} = _encode_keyword($args{keyword});
     }
 
+    _set_root_node_name($param{version});
+
     $self->_send_request(%param);
 }
 
+sub _set_root_node_name {
+    my $version = shift;
+
+    # API 1.00 mistake spelling 'response'
+    $ROOT_NODE = $version eq '1.00' ? 'responce' : 'response';
+}
+
 sub _encode_keyword {
     my $keyword = shift;
     Encode::encode('euc-jp', $keyword);
 }
 
+sub _validate_version_param {
+    my $version = shift;
+
+    unless (defined $version) {
+        return '2.00';
+    }
+
+    my @supported = qw/2.00 1.00/;
+    unless (grep { $version eq $_ } @supported) {
+        Carp::croak("Invalid version '$version'");
+    }
+
+    return $version;
+}
+
 sub _validate_sort_param {
     my $sort = shift;
     my @sort_values = qw(rank +price -price date review);
@@ -178,9 +204,9 @@ sub _parse_response {
     my $dom = XML::LibXML->load_xml(string => $decoded);
 
     my $res = WebService::DMM::Response->new();
-    my $message = _get_or_none($dom, "/responce/result/message", 'TEXT');
+    my $message = _get_or_none($dom, "/$ROOT_NODE/result/message", 'TEXT');
     if (defined $message) {
-        my $cause = _get_or_none($dom, "/responce/result/errors/error/value",
+        my $cause = _get_or_none($dom, "/$ROOT_NODE/result/errors/error/value",
                                  'TEXT');
         $res->cause($cause);
         $res->is_success(0);
@@ -188,7 +214,7 @@ sub _parse_response {
     $res->is_success(1);
 
     for my $p (qw/result_count total_count first_position/) {
-        $res->$p( _get_or_none($dom, "/responce/result/$p", 'TEXT') );
+        $res->$p( _get_or_none($dom, "/$ROOT_NODE/result/$p", 'TEXT') );
     }
 
     $res->items( $self->_parse_items($dom) );
@@ -200,7 +226,7 @@ sub _parse_items {
     my ($self, $dom) = @_;
 
     my @items;
-    my @items_nodes = $dom->findnodes('/responce/result/items/item');
+    my @items_nodes = $dom->findnodes("/$ROOT_NODE/result/items/item");
     for my $item_node (@items_nodes) {
         my %param;
 
@@ -212,6 +238,11 @@ sub _parse_items {
             $param{$p} = $item_node->findvalue($p);
         }
 
+        # for Smart Phone
+        for my $p (qw/URLsp affiliateURLsp/) {
+            $param{$p} = _get_or_none($item_node, $p, 'TEXT');
+        }
+
         my $image_url;
         for my $p (qw/list small large/) {
             $image_url->{$p} = $item_node->findvalue("imageURL/$p");
@@ -517,7 +548,9 @@ I<%params> mandatory parameters are:
 
 =item operation :Str = "ItemList"
 
-=item version :Str = "1.00"
+=item version :Str = "2.00"
+
+Version should be '1.00' or '2.00'.
 
 =item timestamp :Str = current time
 
